@@ -11,8 +11,8 @@ fn main() {
     let name = app.get_name().to_string();
     let outdir = std::path::Path::new(env!("CARGO_MANIFEST_DIR")).join("completions/");
     dbg!(&outdir);
-    generate_to::<Bash, _, _>(&mut app, &name, &outdir).unwrap();
-    generate_to::<Zsh, _, _>(&mut app, &name, &outdir).unwrap();
-    generate_to::<Fish, _, _>(&mut app, &name, &outdir).unwrap();
-    generate_to::<PowerShell, _, _>(&mut app, &name, &outdir).unwrap();
+    generate_to(Bash, &mut app, &name, &outdir).unwrap();
+    generate_to(Zsh, &mut app, &name, &outdir).unwrap();
+    generate_to(Fish, &mut app, &name, &outdir).unwrap();
+    generate_to(PowerShell, &mut app, &name, &outdir).unwrap();
 }
